@@ -12,14 +12,6 @@ from Fishconsole import files
 from Fishconsole import logs
 from Fishconsole import Fishsys
 
-try:
-    from lxml import html
-    etree = html.etree
-except:
-    logs.安全退出("helps依赖包导入出错，程序无法运行")
-
-
-
 # HEI是允许帮助主程序输出消息
 HEI = files.缓存(2, 变量名="HEI")
 if HEI == "error":
@@ -42,12 +34,16 @@ def 帮助():
     :return: <启动主程序>
     """
 
+    global res
     print(logs.颜色(
         "由于termux存在一些问题，所以easygui无法使用而且matplotlib中文辅助模块要使用jupyter notebook才可以使用，这里就不上相关教程了",
         色选="红色"))
 
     if True:
-        a=("我如何重新进入？\n"
+        a=(
+            "后台的占用怎么这么大？\n"
+            "启动时就是这样，但是python有自己的内存回收机制，我们只需等待它慢慢回收即可（我懒得手动释放反正大家内存都8个G起步）\n"
+            "我如何重新进入？\n"
             "导入helps包，然后键入helps.帮助()就可以回来了\n\n"
             "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n"
             "为什么有的地方找不到? \n"
@@ -64,7 +60,7 @@ def 帮助():
             b = a.replace("<换行>", "\n")
         else:
             if Fishsys.官网存活性检测():
-                if FHUM == True:
+                if FHUM:
                     a = Fishsys.讯飞云控("2fqV7")["a"]
                     a=a.replace("<换行>", "\n")
                     files.缓存(3, 数据={"FHUM": False})
@@ -489,13 +485,8 @@ def 帮助():
                                 "一个工程如果大起来了的话，为了可以更好的运行，就免不了使用配置文件，但是，按照普通的读取方式就是读写一个文件的话，一堆文件就会把我们搞的惊慌失措，所以我整了个这个玩意儿，它相当于是暂时帮我们解决了这个问题，现在是用列表存的，以后可能会改成字典，这要取决于我自己的体验，如果体验实在难以接受，我tm。。。"
                                 "\n-----------------------------\n\n"
                                 "语法就是\n\n"
-                                "files.缓存(模式, '字典数据','文件名','变量名'\n（请注意，字符串用单引号括起来，千万不要用双引号，否则将过不了加密',缓存文件的名字)\n\n"
-                                "模式有三种\n\n1:写\n覆写模式就是创建缓存文件，你需要两个模式和缓存一起使用\n\n2：读\n你只需要两个参数（模式，文件名），他会返回给你一个列表\n但如果你在之前没有创建文件，那么我们将会返回一个布尔值（False）\n\n3：插入模式，你只需要指定一个dict，dict中填写你想改变或插入的dict键值对，我们就会直接在原来的缓存文件中将他们插入进去"
-                                "但是每次都在后面指定文件的名字的话就有点废手了，为了避免这种情况，我们可以在开头就指定好文件的名字，这样就可以了\n\n"
-                                "示例语法\n"
-                                "Filename='1.txt'\n"
-                                "a = 缓存(1, 数据='{'a':123,'b':456}',文件名=Filename) #覆写模式\n"
-                                "a = 缓存(2,变量名='a',文件名=Filename) #读模式\n"
-                                "a = 缓存(3,文件名=Filename,数据='{'a':123,'b':456}') #插入/修改模式\n"
+                                "files.缓存(1,数据={})【这个是覆盖写入，原来的所有东西会消失】\n\n"
+                                "files.缓存(2,变量名='缓存名')【这个是读取，如果你指定了变量名，我们就会返回这个值对应的内容,反之返回全部（返回全部是针对大规模读写性能太差的问题的解决方案）】\n\n"
+                                "files.缓存(3,数据)【这个是插入，修改或增加部分缓存内容】"
                                 , "缓存模块", "ok")
 
